@@ -1544,6 +1544,252 @@ class CfnEnvironmentProps():
         return 'CfnEnvironmentProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.implements(_IInspectable_051e6ed8)
+class CfnHostedConfigurationVersion(_CfnResource_7760e8e4, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_appconfig.CfnHostedConfigurationVersion"):
+    """A CloudFormation ``AWS::AppConfig::HostedConfigurationVersion``.
+
+    see
+    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html
+    cloudformationResource:
+    :cloudformationResource:: AWS::AppConfig::HostedConfigurationVersion
+    """
+    def __init__(self, scope: _Construct_f50a3f53, id: str, *, application_id: str, configuration_profile_id: str, content: str, content_type: str, description: typing.Optional[str]=None, latest_version_number: typing.Optional[jsii.Number]=None) -> None:
+        """Create a new ``AWS::AppConfig::HostedConfigurationVersion``.
+
+        :param scope: - scope in which this resource is defined.
+        :param id: - scoped id of the resource.
+        :param application_id: ``AWS::AppConfig::HostedConfigurationVersion.ApplicationId``.
+        :param configuration_profile_id: ``AWS::AppConfig::HostedConfigurationVersion.ConfigurationProfileId``.
+        :param content: ``AWS::AppConfig::HostedConfigurationVersion.Content``.
+        :param content_type: ``AWS::AppConfig::HostedConfigurationVersion.ContentType``.
+        :param description: ``AWS::AppConfig::HostedConfigurationVersion.Description``.
+        :param latest_version_number: ``AWS::AppConfig::HostedConfigurationVersion.LatestVersionNumber``.
+        """
+        props = CfnHostedConfigurationVersionProps(application_id=application_id, configuration_profile_id=configuration_profile_id, content=content, content_type=content_type, description=description, latest_version_number=latest_version_number)
+
+        jsii.create(CfnHostedConfigurationVersion, self, [scope, id, props])
+
+    @jsii.member(jsii_name="fromCloudFormation")
+    @builtins.classmethod
+    def from_cloud_formation(cls, scope: _Construct_f50a3f53, id: str, resource_attributes: typing.Any, *, finder: _ICfnFinder_3b168f30) -> "CfnHostedConfigurationVersion":
+        """A factory method that creates a new instance of this class from an object containing the CloudFormation properties of this resource.
+
+        Used in the @aws-cdk/cloudformation-include module.
+
+        :param scope: -
+        :param id: -
+        :param resource_attributes: -
+        :param finder: The finder interface used to resolve references across the template.
+
+        stability
+        :stability: experimental
+        """
+        options = _FromCloudFormationOptions_5f49f6f1(finder=finder)
+
+        return jsii.sinvoke(cls, "fromCloudFormation", [scope, id, resource_attributes, options])
+
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: _TreeInspector_154f5999) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
+    @jsii.member(jsii_name="renderProperties")
+    def _render_properties(self, props: typing.Mapping[str, typing.Any]) -> typing.Mapping[str, typing.Any]:
+        """
+        :param props: -
+        """
+        return jsii.invoke(self, "renderProperties", [props])
+
+    @jsii.python.classproperty
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
+        """The CloudFormation resource type name for this resource class."""
+        return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
+
+    @builtins.property
+    @jsii.member(jsii_name="cfnProperties")
+    def _cfn_properties(self) -> typing.Mapping[str, typing.Any]:
+        return jsii.get(self, "cfnProperties")
+
+    @builtins.property
+    @jsii.member(jsii_name="applicationId")
+    def application_id(self) -> str:
+        """``AWS::AppConfig::HostedConfigurationVersion.ApplicationId``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html#cfn-appconfig-hostedconfigurationversion-applicationid
+        """
+        return jsii.get(self, "applicationId")
+
+    @application_id.setter
+    def application_id(self, value: str) -> None:
+        jsii.set(self, "applicationId", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="configurationProfileId")
+    def configuration_profile_id(self) -> str:
+        """``AWS::AppConfig::HostedConfigurationVersion.ConfigurationProfileId``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html#cfn-appconfig-hostedconfigurationversion-configurationprofileid
+        """
+        return jsii.get(self, "configurationProfileId")
+
+    @configuration_profile_id.setter
+    def configuration_profile_id(self, value: str) -> None:
+        jsii.set(self, "configurationProfileId", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="content")
+    def content(self) -> str:
+        """``AWS::AppConfig::HostedConfigurationVersion.Content``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html#cfn-appconfig-hostedconfigurationversion-content
+        """
+        return jsii.get(self, "content")
+
+    @content.setter
+    def content(self, value: str) -> None:
+        jsii.set(self, "content", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="contentType")
+    def content_type(self) -> str:
+        """``AWS::AppConfig::HostedConfigurationVersion.ContentType``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html#cfn-appconfig-hostedconfigurationversion-contenttype
+        """
+        return jsii.get(self, "contentType")
+
+    @content_type.setter
+    def content_type(self, value: str) -> None:
+        jsii.set(self, "contentType", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="description")
+    def description(self) -> typing.Optional[str]:
+        """``AWS::AppConfig::HostedConfigurationVersion.Description``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html#cfn-appconfig-hostedconfigurationversion-description
+        """
+        return jsii.get(self, "description")
+
+    @description.setter
+    def description(self, value: typing.Optional[str]) -> None:
+        jsii.set(self, "description", value)
+
+    @builtins.property
+    @jsii.member(jsii_name="latestVersionNumber")
+    def latest_version_number(self) -> typing.Optional[jsii.Number]:
+        """``AWS::AppConfig::HostedConfigurationVersion.LatestVersionNumber``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html#cfn-appconfig-hostedconfigurationversion-latestversionnumber
+        """
+        return jsii.get(self, "latestVersionNumber")
+
+    @latest_version_number.setter
+    def latest_version_number(self, value: typing.Optional[jsii.Number]) -> None:
+        jsii.set(self, "latestVersionNumber", value)
+
+
+@jsii.data_type(jsii_type="monocdk-experiment.aws_appconfig.CfnHostedConfigurationVersionProps", jsii_struct_bases=[], name_mapping={'application_id': 'applicationId', 'configuration_profile_id': 'configurationProfileId', 'content': 'content', 'content_type': 'contentType', 'description': 'description', 'latest_version_number': 'latestVersionNumber'})
+class CfnHostedConfigurationVersionProps():
+    def __init__(self, *, application_id: str, configuration_profile_id: str, content: str, content_type: str, description: typing.Optional[str]=None, latest_version_number: typing.Optional[jsii.Number]=None) -> None:
+        """Properties for defining a ``AWS::AppConfig::HostedConfigurationVersion``.
+
+        :param application_id: ``AWS::AppConfig::HostedConfigurationVersion.ApplicationId``.
+        :param configuration_profile_id: ``AWS::AppConfig::HostedConfigurationVersion.ConfigurationProfileId``.
+        :param content: ``AWS::AppConfig::HostedConfigurationVersion.Content``.
+        :param content_type: ``AWS::AppConfig::HostedConfigurationVersion.ContentType``.
+        :param description: ``AWS::AppConfig::HostedConfigurationVersion.Description``.
+        :param latest_version_number: ``AWS::AppConfig::HostedConfigurationVersion.LatestVersionNumber``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html
+        """
+        self._values = {
+            'application_id': application_id,
+            'configuration_profile_id': configuration_profile_id,
+            'content': content,
+            'content_type': content_type,
+        }
+        if description is not None: self._values["description"] = description
+        if latest_version_number is not None: self._values["latest_version_number"] = latest_version_number
+
+    @builtins.property
+    def application_id(self) -> str:
+        """``AWS::AppConfig::HostedConfigurationVersion.ApplicationId``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html#cfn-appconfig-hostedconfigurationversion-applicationid
+        """
+        return self._values.get('application_id')
+
+    @builtins.property
+    def configuration_profile_id(self) -> str:
+        """``AWS::AppConfig::HostedConfigurationVersion.ConfigurationProfileId``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html#cfn-appconfig-hostedconfigurationversion-configurationprofileid
+        """
+        return self._values.get('configuration_profile_id')
+
+    @builtins.property
+    def content(self) -> str:
+        """``AWS::AppConfig::HostedConfigurationVersion.Content``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html#cfn-appconfig-hostedconfigurationversion-content
+        """
+        return self._values.get('content')
+
+    @builtins.property
+    def content_type(self) -> str:
+        """``AWS::AppConfig::HostedConfigurationVersion.ContentType``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html#cfn-appconfig-hostedconfigurationversion-contenttype
+        """
+        return self._values.get('content_type')
+
+    @builtins.property
+    def description(self) -> typing.Optional[str]:
+        """``AWS::AppConfig::HostedConfigurationVersion.Description``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html#cfn-appconfig-hostedconfigurationversion-description
+        """
+        return self._values.get('description')
+
+    @builtins.property
+    def latest_version_number(self) -> typing.Optional[jsii.Number]:
+        """``AWS::AppConfig::HostedConfigurationVersion.LatestVersionNumber``.
+
+        see
+        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-appconfig-hostedconfigurationversion.html#cfn-appconfig-hostedconfigurationversion-latestversionnumber
+        """
+        return self._values.get('latest_version_number')
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return 'CfnHostedConfigurationVersionProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
 __all__ = [
     "CfnApplication",
     "CfnApplicationProps",
@@ -1555,6 +1801,8 @@ __all__ = [
     "CfnDeploymentStrategyProps",
     "CfnEnvironment",
     "CfnEnvironmentProps",
+    "CfnHostedConfigurationVersion",
+    "CfnHostedConfigurationVersionProps",
 ]
 
 publication.publish()
