@@ -784,7 +784,7 @@ class BackupVaultProps():
         """Properties for a BackupVault.
 
         :param access_policy: A resource-based policy that is used to manage access permissions on the backup vault. Default: - access is not restricted
-        :param backup_vault_name: The name of a logical container where backups are stored. Default: - A CDK generated name
+        :param backup_vault_name: The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. Default: - A CDK generated name
         :param encryption_key: The server-side encryption key to use to protect your backups. Default: - an Amazon managed KMS key
         :param notification_events: The vault events to send. Default: - all vault events if ``notificationTopic`` is defined
         :param notification_topic: A SNS topic to send vault events to. Default: - no notifications
@@ -818,6 +818,10 @@ class BackupVaultProps():
     def backup_vault_name(self) -> typing.Optional[str]:
         """The name of a logical container where backups are stored.
 
+        Backup vaults
+        are identified by names that are unique to the account used to create
+        them and the AWS Region where they are created.
+
         default
         :default: - A CDK generated name
 
@@ -2219,7 +2223,7 @@ class BackupVault(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocd
         :param scope: -
         :param id: -
         :param access_policy: A resource-based policy that is used to manage access permissions on the backup vault. Default: - access is not restricted
-        :param backup_vault_name: The name of a logical container where backups are stored. Default: - A CDK generated name
+        :param backup_vault_name: The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the AWS Region where they are created. Default: - A CDK generated name
         :param encryption_key: The server-side encryption key to use to protect your backups. Default: - an Amazon managed KMS key
         :param notification_events: The vault events to send. Default: - all vault events if ``notificationTopic`` is defined
         :param notification_topic: A SNS topic to send vault events to. Default: - no notifications
