@@ -10,7 +10,8 @@ import publication
 
 from .._jsii import *
 
-from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, IResolvable as _IResolvable_9ceae33e, IInspectable as _IInspectable_051e6ed8)
+from .. import (CfnResource as _CfnResource_7760e8e4, Construct as _Construct_f50a3f53, FromCloudFormationOptions as _FromCloudFormationOptions_5f49f6f1, TreeInspector as _TreeInspector_154f5999, IResolvable as _IResolvable_9ceae33e, IInspectable as _IInspectable_051e6ed8, Resource as _Resource_884d0774, SecretValue as _SecretValue_99478b8b, IResource as _IResource_72f7ee7e)
+from ..aws_s3 import (IBucket as _IBucket_25bad983)
 
 
 @jsii.implements(_IInspectable_051e6ed8)
@@ -371,9 +372,287 @@ class CfnGitHubRepositoryProps():
         return 'CfnGitHubRepositoryProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.data_type(jsii_type="monocdk-experiment.aws_codestar.GitHubRepositoryProps", jsii_struct_bases=[], name_mapping={'access_token': 'accessToken', 'contents_bucket': 'contentsBucket', 'contents_key': 'contentsKey', 'owner': 'owner', 'repository_name': 'repositoryName', 'contents_s3_version': 'contentsS3Version', 'description': 'description', 'enable_issues': 'enableIssues', 'visibility': 'visibility'})
+class GitHubRepositoryProps():
+    def __init__(self, *, access_token: _SecretValue_99478b8b, contents_bucket: _IBucket_25bad983, contents_key: str, owner: str, repository_name: str, contents_s3_version: typing.Optional[str]=None, description: typing.Optional[str]=None, enable_issues: typing.Optional[bool]=None, visibility: typing.Optional["RepositoryVisibility"]=None) -> None:
+        """Construction properties of {@link GitHubRepository}.
+
+        :param access_token: The GitHub user's personal access token for the GitHub repository.
+        :param contents_bucket: The name of the Amazon S3 bucket that contains the ZIP file with the content to be committed to the new repository.
+        :param contents_key: The S3 object key or file name for the ZIP file.
+        :param owner: The GitHub user name for the owner of the GitHub repository to be created. If this repository should be owned by a GitHub organization, provide its name
+        :param repository_name: The name of the repository you want to create in GitHub with AWS CloudFormation stack creation.
+        :param contents_s3_version: The object version of the ZIP file, if versioning is enabled for the Amazon S3 bucket. Default: - not specified
+        :param description: A comment or description about the new repository. This description is displayed in GitHub after the repository is created. Default: - no description
+        :param enable_issues: Indicates whether to enable issues for the GitHub repository. You can use GitHub issues to track information and bugs for your repository. Default: true
+        :param visibility: Indicates whether the GitHub repository is a private repository. If so, you choose who can see and commit to this repository. Default: RepositoryVisibility.PUBLIC
+
+        stability
+        :stability: experimental
+        """
+        self._values = {
+            'access_token': access_token,
+            'contents_bucket': contents_bucket,
+            'contents_key': contents_key,
+            'owner': owner,
+            'repository_name': repository_name,
+        }
+        if contents_s3_version is not None: self._values["contents_s3_version"] = contents_s3_version
+        if description is not None: self._values["description"] = description
+        if enable_issues is not None: self._values["enable_issues"] = enable_issues
+        if visibility is not None: self._values["visibility"] = visibility
+
+    @builtins.property
+    def access_token(self) -> _SecretValue_99478b8b:
+        """The GitHub user's personal access token for the GitHub repository.
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('access_token')
+
+    @builtins.property
+    def contents_bucket(self) -> _IBucket_25bad983:
+        """The name of the Amazon S3 bucket that contains the ZIP file with the content to be committed to the new repository.
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('contents_bucket')
+
+    @builtins.property
+    def contents_key(self) -> str:
+        """The S3 object key or file name for the ZIP file.
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('contents_key')
+
+    @builtins.property
+    def owner(self) -> str:
+        """The GitHub user name for the owner of the GitHub repository to be created.
+
+        If this
+        repository should be owned by a GitHub organization, provide its name
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('owner')
+
+    @builtins.property
+    def repository_name(self) -> str:
+        """The name of the repository you want to create in GitHub with AWS CloudFormation stack creation.
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('repository_name')
+
+    @builtins.property
+    def contents_s3_version(self) -> typing.Optional[str]:
+        """The object version of the ZIP file, if versioning is enabled for the Amazon S3 bucket.
+
+        default
+        :default: - not specified
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('contents_s3_version')
+
+    @builtins.property
+    def description(self) -> typing.Optional[str]:
+        """A comment or description about the new repository.
+
+        This description is displayed in GitHub after the repository
+        is created.
+
+        default
+        :default: - no description
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('description')
+
+    @builtins.property
+    def enable_issues(self) -> typing.Optional[bool]:
+        """Indicates whether to enable issues for the GitHub repository.
+
+        You can use GitHub issues to track information
+        and bugs for your repository.
+
+        default
+        :default: true
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('enable_issues')
+
+    @builtins.property
+    def visibility(self) -> typing.Optional["RepositoryVisibility"]:
+        """Indicates whether the GitHub repository is a private repository.
+
+        If so, you choose who can see and commit to
+        this repository.
+
+        default
+        :default: RepositoryVisibility.PUBLIC
+
+        stability
+        :stability: experimental
+        """
+        return self._values.get('visibility')
+
+    def __eq__(self, rhs) -> bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs) -> bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return 'GitHubRepositoryProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+
+
+@jsii.interface(jsii_type="monocdk-experiment.aws_codestar.IGitHubRepository")
+class IGitHubRepository(_IResource_72f7ee7e, jsii.compat.Protocol):
+    """GitHubRepository resource interface.
+
+    stability
+    :stability: experimental
+    """
+    @builtins.staticmethod
+    def __jsii_proxy_class__():
+        return _IGitHubRepositoryProxy
+
+    @builtins.property
+    @jsii.member(jsii_name="owner")
+    def owner(self) -> str:
+        """the repository owner.
+
+        stability
+        :stability: experimental
+        """
+        ...
+
+    @builtins.property
+    @jsii.member(jsii_name="repo")
+    def repo(self) -> str:
+        """the repository name.
+
+        stability
+        :stability: experimental
+        """
+        ...
+
+
+class _IGitHubRepositoryProxy(jsii.proxy_for(_IResource_72f7ee7e)):
+    """GitHubRepository resource interface.
+
+    stability
+    :stability: experimental
+    """
+    __jsii_type__ = "monocdk-experiment.aws_codestar.IGitHubRepository"
+    @builtins.property
+    @jsii.member(jsii_name="owner")
+    def owner(self) -> str:
+        """the repository owner.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "owner")
+
+    @builtins.property
+    @jsii.member(jsii_name="repo")
+    def repo(self) -> str:
+        """the repository name.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "repo")
+
+
+@jsii.enum(jsii_type="monocdk-experiment.aws_codestar.RepositoryVisibility")
+class RepositoryVisibility(enum.Enum):
+    """Visibility of the GitHubRepository.
+
+    stability
+    :stability: experimental
+    """
+    PRIVATE = "PRIVATE"
+    """private repository.
+
+    stability
+    :stability: experimental
+    """
+    PUBLIC = "PUBLIC"
+    """public repository.
+
+    stability
+    :stability: experimental
+    """
+
+@jsii.implements(IGitHubRepository)
+class GitHubRepository(_Resource_884d0774, metaclass=jsii.JSIIMeta, jsii_type="monocdk-experiment.aws_codestar.GitHubRepository"):
+    """The GitHubRepository resource.
+
+    stability
+    :stability: experimental
+    """
+    def __init__(self, scope: _Construct_f50a3f53, id: str, *, access_token: _SecretValue_99478b8b, contents_bucket: _IBucket_25bad983, contents_key: str, owner: str, repository_name: str, contents_s3_version: typing.Optional[str]=None, description: typing.Optional[str]=None, enable_issues: typing.Optional[bool]=None, visibility: typing.Optional["RepositoryVisibility"]=None) -> None:
+        """
+        :param scope: -
+        :param id: -
+        :param access_token: The GitHub user's personal access token for the GitHub repository.
+        :param contents_bucket: The name of the Amazon S3 bucket that contains the ZIP file with the content to be committed to the new repository.
+        :param contents_key: The S3 object key or file name for the ZIP file.
+        :param owner: The GitHub user name for the owner of the GitHub repository to be created. If this repository should be owned by a GitHub organization, provide its name
+        :param repository_name: The name of the repository you want to create in GitHub with AWS CloudFormation stack creation.
+        :param contents_s3_version: The object version of the ZIP file, if versioning is enabled for the Amazon S3 bucket. Default: - not specified
+        :param description: A comment or description about the new repository. This description is displayed in GitHub after the repository is created. Default: - no description
+        :param enable_issues: Indicates whether to enable issues for the GitHub repository. You can use GitHub issues to track information and bugs for your repository. Default: true
+        :param visibility: Indicates whether the GitHub repository is a private repository. If so, you choose who can see and commit to this repository. Default: RepositoryVisibility.PUBLIC
+
+        stability
+        :stability: experimental
+        """
+        props = GitHubRepositoryProps(access_token=access_token, contents_bucket=contents_bucket, contents_key=contents_key, owner=owner, repository_name=repository_name, contents_s3_version=contents_s3_version, description=description, enable_issues=enable_issues, visibility=visibility)
+
+        jsii.create(GitHubRepository, self, [scope, id, props])
+
+    @builtins.property
+    @jsii.member(jsii_name="owner")
+    def owner(self) -> str:
+        """the repository owner.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "owner")
+
+    @builtins.property
+    @jsii.member(jsii_name="repo")
+    def repo(self) -> str:
+        """the repository name.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.get(self, "repo")
+
+
 __all__ = [
     "CfnGitHubRepository",
     "CfnGitHubRepositoryProps",
+    "GitHubRepository",
+    "GitHubRepositoryProps",
+    "IGitHubRepository",
+    "RepositoryVisibility",
 ]
 
 publication.publish()
